==> qt-creator-opensource-src-4.0.1.tar.gz: qt-creator-opensource-src-4.0.1/src/libs/modelinglib/qmt/tasks/alignonrastervisitor.h <==
/****************************************************************************
**
** Copyright (C) 2016 Jochen Becher
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef QMT_ALIGNONRASTERVISITOR_H
#define QMT_ALIGNONRASTERVISITOR_H

#include "qmt/diagram/dvisitor.h"
#include "qmt/infrastructure/qmt_global.h"

namespace qmt {

class DiagramController;
class ISceneInspector;
class MDiagram;

class QMT_EXPORT AlignOnRasterVisitor : public DVisitor
{
public:
    AlignOnRasterVisitor();
    ~AlignOnRasterVisitor();

    void setDiagramController(DiagramController *diagramController);
    void setSceneInspector(ISceneInspector *sceneInspector);
    void setDiagram(MDiagram *diagram);

    void visitDElement(DElement *element) override;
    void visitDObject(DObject *object) override;
    void visitDPackage(DPackage *package) override;
    void visitDClass(DClass *klass) override;
    void visitDComponent(DComponent *component) override;
    void visitDDiagram(DDiagram *diagram) override;
    void visitDItem(DItem *item) override;
    void visitDRelation(DRelation *relation) override;
    void visitDInheritance(DInheritance *inheritance) override;
    void visitDDependency(DDependency *dependency) override;
    void visitDAssociation(DAssociation *association) override;
    void visitDAnnotation(DAnnotation *annotation) override;
    void visitDBoundary(DBoundary *boundary) override;

private:
    DiagramController *m_diagramController;
    ISceneInspector *m_sceneInspector;
    MDiagram *m_diagram;
};

} // namespace qmt

#endif // QMT_ALIGNONRASTERVISITOR_H

==> qt-creator-opensource-src-4.2.2.tar.gz: qt-creator-opensource-src-4.2.2/src/libs/modelinglib/qmt/tasks/alignonrastervisitor.h <==
/****************************************************************************
**
** Copyright (C) 2016 Jochen Becher
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "qmt/diagram/dvisitor.h"
#include "qmt/infrastructure/qmt_global.h"

namespace qmt {

class DiagramController;
class ISceneInspector;
class MDiagram;

class QMT_EXPORT AlignOnRasterVisitor : public DVisitor
{
public:
    AlignOnRasterVisitor();
    ~AlignOnRasterVisitor();

    void setDiagramController(DiagramController *diagramController);
    void setSceneInspector(ISceneInspector *sceneInspector);
    void setDiagram(MDiagram *diagram);

    void visitDElement(DElement *element) override;
    void visitDObject(DObject *object) override;
    void visitDPackage(DPackage *package) override;
    void visitDClass(DClass *klass) override;
    void visitDComponent(DComponent *component) override;
    void visitDDiagram(DDiagram *diagram) override;
    void visitDItem(DItem *item) override;
    void visitDRelation(DRelation *relation) override;
    void visitDInheritance(DInheritance *inheritance) override;
    void visitDDependency(DDependency *dependency) override;
    void visitDAssociation(DAssociation *association) override;
    void visitDAnnotation(DAnnotation *annotation) override;
    void visitDBoundary(DBoundary *boundary) override;

private:
    DiagramController *m_diagramController;
    ISceneInspector *m_sceneInspector;
    MDiagram *m_diagram;
};

} // namespace qmt
